#!/usr/bin/env python 3
# -*- coding: utf-8 -*-

#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
"""
nn 相关工具

Authors: panxu(panxu@baidu.com)
Date:    2020/06/01 15:39:00
"""
